# Two-Disc Cycloidal Gearbox Design

## 1. Project Description
The two-disc cycloidal gearbox is designed to convert high-speed, low-torque input from a stepper motor into low-speed, high-torque output. It utilizes two synchronized cycloidal discs that rotate in opposite phases, interacting with drive pins to transmit motion to an output shaft.

This configuration minimizes backlash and distributes load across multiple contact points, offering smooth and powerful transmission. The system is fully enclosed and features multiple mounting options for external attachments.

Scalability:
Thanks to its parametric design, the gearbox can be scaled up for larger loads or resized to fit custom dimensions. The disc radius, bolt spacing, and housing can all be edited easily via CAD.

## 2. Application & Use Cases

### Applications
- Robotics joints and arms
- CNC rotary tables
- Precision camera mounts
- Automated actuators
- Small-scale industrial machines

### How to Use
- Mount the gearbox base to your frame using the provided holes.

- Connect the NEMA-17 motor shaft to the input via the motor shaft connector.

- Attach your load or mechanism to the output shaft area.

- Power the motor through a driver board and microcontroller (e.g., Arduino).

- Control the motion using programmed step sequences.

    - Ensure lubrication (grease) between the discs and drive pins for smoother performance and longer lifespan.


## 3.  Engineering Drawings

### Description
The design is a compact, scalable cycloidal gearbox featuring two cycloidal discs, intended for high-torque, low-speed applications. The modular nature allows for modifications in both size and material type. The current version has a diameter of 90 mm and a height of 54 mm.

- 2D & 3D Engineering Drawings Include:
    - Exploded view

    - Cross-sectional view

    - Isometric View

    - Dimensional tolerances

    - Shaft alignment and key interfaces

    - Mounting hole patterns

## 4. List of Materials & Components

### Standard Components

| Part          | Quantity | Approx. Size                                       | Notes                   |
| ------------- | -------- | -------------------------------------------------- | ----------------------- |
| Bearing       | 2        | Ø65 mm (outer) × Ø50 mm (inner) × 7 mm (thickness) | Output shaft support    |
| Bearing       | 4        | Ø32 mm (outer) × Ø20 mm (inner) × 7 mm (thickness) | Disc and input supports |
| Stepper Motor | 1        | NEMA-17                                            | Input source            |

### Bolts & Nuts (*with available size approximations*)

Note: If a bolt is slightly longer than needed, it can be trimmed using a saw. Nut sizes should fit snugly but not too tight.

1. Connecting Base to Base Cover
    - 7 × Bolts: Approx. M6 × 45 mm (Head Ø ≈ 7 mm)
    - 7 × Nuts: M6 (Edge-to-edge ≈ 6.8 mm, Thickness ≈ 3 mm)

2. Drive Pins Area (Replaces traditional 5 mm pins)
    - 4 × Bolts: Approx. M6 × 48 mm (Head Ø ≈ 6.2 mm)
    - 4 × Nuts: M6 (Edge-to-edge ≈ 6.8 mm, Thickness ≈ 3 mm)

3. Mounting Points on Top of Gearbox
    - 7 × Nuts: M6 (Edge-to-edge ≈ 6.8 mm, Thickness ≈ 3 mm)

4. Shaft Connector
    - 2 × Bolts: Approx. M5 × 40 mm
    - 2 × Nuts: M5 (Edge-to-edge ≈ 5.4 mm, Thickness ≈ 2.5 mm)

5. NEMA-17 Shaft Connector
    - 1 × Bolt: Approx. M3 × 6 mm (Head Ø ≈ 3 mm)
        - May require slight sanding to fit perfectly.
    - 1 × Nut: M3 (Edge-to-edge ≈ 5.4 mm, Thickness ≈ 2.5 mm)

### 3D-Printed Components
- Material: PLA (tested), PETG (recommended for durability)
- Parts: Housing, base cover, discs, shaft connectors, output caps, circlips
- Infill: Suggested 40% or more for torque applications
